## Contributing
Please feel free to contribute!

### Guidelines
1. Please search the issues tab before opening a pull-request and open new issues if necessary.
2. If your PR includes an enhancement, please write unit tests to go along with it.
3. Run tests on your local machine before opening a pull-request (see below)

### Testing
Tests are written and run using `pytest`.
Ensure you have pytest installed using 
`sage -pip install pytest`

To run tests, in the repository root directory simply run `sage -python -m pytest ./cgt`.
